@@ -10,7 +10,7 @@ use Encode qw(encode_utf8 decode_utf8);
 use Carp;
 use utf8;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =encoding utf8
 
@@ -191,7 +191,10 @@ Get all keys as a list.
 
 sub keys {
     my ($self) = @_;
-    return keys %{$self->{cache}};
+
+    return map {
+        eval { decode_utf8($_) } || $_
+    } keys %{$self->{cache}};
 }
 
 =head2 clear()
